# See section 8.4 of Technical Specification
ALLOWED_NOTIFICATION_TEXTS = {
    "de": "NICHT ZUR ZAHLUNG VERWENDEN",
    "fr": "NE PAS UTILISER POUR LE PAIEMENT",
    "it": "NON UTILIZZARE PER IL PAGAMENTO",
    "en": "DO NOT USE FOR PAYMENT",
}

# Language translations for QR-bill headings
TRANSLATIONS = {
    "en": {
        "payment_part": "Payment part",
        "receipt": "Receipt",
        "account_payable_to": "Account / Payable to",
        "reference": "Reference",
        "additional_information": "Additional information",
        "currency": "Currency",
        "amount": "Amount",
        "acceptance_point": "Acceptance point",
        "payable_by": "Payable by",
        "payable_by_name_address": "Payable by (name/address)",
    },
    "de": {
        "payment_part": "Zahlteil",
        "receipt": "Empfangsschein",
        "account_payable_to": "Konto / Zahlbar an",
        "reference": "Referenz",
        "additional_information": "Zusätzliche Informationen",
        "currency": "Währung",
        "amount": "Betrag",
        "acceptance_point": "Annahmestelle",
        "payable_by": "Zahlbar durch",
        "payable_by_name_address": "Zahlbar durch (Name/Adresse)",
    },
    "fr": {
        "payment_part": "Section paiement",
        "receipt": "Récépissé",
        "account_payable_to": "Compte / Payable à",
        "reference": "Référence",
        "additional_information": "Informations supplémentaires",
        "currency": "Monnaie",
        "amount": "Montant",
        "acceptance_point": "Point de dépôt",
        "payable_by": "Payable par",
        "payable_by_name_address": "Payable par (nom/adresse)",
    },
    "it": {
        "payment_part": "Sezione pagamento",
        "receipt": "Ricevuta",
        "account_payable_to": "Conto / Pagabile a",
        "reference": "Riferimento",
        "additional_information": "Informazioni supplementari",
        "currency": "Valuta",
        "amount": "Importo",
        "acceptance_point": "Punto di accettazione",
        "payable_by": "Pagabile da",
        "payable_by_name_address": "Pagabile da (nome/indirizzo)",
    },
}
